=============
Release Notes
=============

When projects release a new version, they often include "release notes" with information
about improvements, bug-fixes, and other changes. These projects are the best source
of information about what has recently changed.

Below you'll find links to the release notes for several major projects in the
Jupyter ecosystem.

Jupyter Notebook
================

You can find a changelog at
`the Jupyter Notebook documentation <https://jupyter-notebook.readthedocs.io/en/stable/changelog.html>`_.

JupyterLab
==========

You can find a changelog at
`the JupyterLab documentation <https://jupyterlab.readthedocs.io/en/stable/getting_started/changelog.html>`_.

JupyterHub
==========

You can find a changelog at
`the JupyterHub documentation <https://jupyterhub.readthedocs.io/en/stable/reference/changelog.html>`_.
